@@ -84,7 +84,7 @@
 #define QUICKADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef QUICKADDONS_NO_DEPRECATED
-#  define QUICKADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define QUICKADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef QUICKADDONS_NO_DEPRECATED_WARNINGS
 #  define QUICKADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef QUICKADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define QUICKADDONS_DEPRECATED_WARNINGS_SINCE QUICKADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define QUICKADDONS_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define QUICKADDONS_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
